Struct SctkPopupSettings
pub struct SctkPopupSettings {
pub parent: Id,
pub id: Id,
pub positioner: SctkPositioner,
pub parent_size: Option<(u32, u32)>,
pub grab: bool,
pub close_with_children: bool,
pub input_zone: Option<Vec<Rectangle>>,
}Expand description
Popup creation details
Fields
parent: IdXXX must be unique, id of the parent
id: IdXXX must be unique, id of the popup
positioner: SctkPositionerpositioner of the popup
parent_size: Option<(u32, u32)>optional parent size, must be correct if specified or the behavior is undefined
grab: boolwhether a grab should be requested for the popup after creation
close_with_children: boolwhether a popup should close when its child popups close
input_zone: Option<Vec<Rectangle>>input zone None results in accepting all input