Struct SctkPositioner

pub struct SctkPositioner {
    pub size: Option<(u32, u32)>,
    pub size_limits: Limits,
    pub anchor_rect: Rectangle<i32>,
    pub anchor: Anchor,
    pub gravity: Gravity,
    pub constraint_adjustment: u32,
    pub offset: (i32, i32),
    pub reactive: bool,
}
Positioner of a popup

Fields

size: Option<(u32, u32)>

size of the popup (if it is None, the popup will be autosized)

size_limits: Limits

Limits of the popup size

anchor_rect: Rectangle<i32>

the rectangle which the popup will be anchored to

anchor: Anchor

the anchor location on the popup

gravity: Gravity

the gravity of the popup

constraint_adjustment: u32

the constraint adjustment, Specify how the window should be positioned if the originally intended position caused the surface to be constrained, meaning at least partially outside positioning boundaries set by the compositor. The adjustment is set by constructing a bitmask describing the adjustment to be made when the surface is constrained on that axis. If no bit for one axis is set, the compositor will assume that the child surface should not change its position on that axis when constrained.

If more than one bit for one axis is set, the order of how adjustments are applied is specified in the corresponding adjustment descriptions.

The default adjustment is none.

offset: (i32, i32)

offset of the popup

reactive: bool

whether the popup is reactive